@@ -19,7 +19,7 @@ def ocr_result_image(result, input_image, output_image='output_image.png'):
     boxes = [line[0] for line in result]
     txts = [line[1][0] for line in result]
     scores = [line[1][1] for line in result]
-    im_show = draw_ocr(image, boxes, txts, scores, font_path=get_module_path("./data/simfang.ttf", __file__))
+    im_show = draw_ocr(image, boxes, txts, scores, font_path=get_module_path("../data/simfang.ttf", __file__))
     im_show = Image.fromarray(im_show)
     im_show.save(output_image)
     return output_image
